==> iwrite-1.0.1.4.tar.gz: iwrite-1.0.1.4/src/item_text.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_text_h__

#include "item_common.h"
#include "item_method.h"

struct item_text
{
  double                                m_pos_x1;
  double                                m_pos_y1;
  double                                m_pos_x2;
  double                                m_pos_y2;
  PangoFontDescription*                 m_font; 
  GdkRGBA                               m_color;
  int                                   m_rotate;
  gdouble                               m_rotation;
  int                                   m_autowrap;
  char*                                 m_text;
  char*                                 m_value;
};

extern void
item_text_assign(
  struct item_text*const                o_text,
  struct item_method*const              o_method);

extern void
item_text_extent_update(
  struct item_text*const                io_text);

extern void
item_text_get_bbox(
  struct geom_rect*const                o_bbox,
  int*const                             o_overlay,
  void const*const                      i_object);

extern void
item_text_in_event(
  enum event_type*const                 o_type,
  struct item_text const*const          i_text,
  struct item_in_event const*const      i_ctx);

extern void
item_text_discharge(
  struct item_text*const                io_text);

extern void
item_text_draw(
  struct item_text      *               i_text,
  struct item_draw_context const*const  i_ctx);

extern void
item_text_move(
  struct item_text*const                io_text,
  struct geom_point const*const         i_event);

extern void
item_text_normalize(
  struct item_text*const                io_text,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_text_property(
  struct item_text*const                io_text);

extern int
item_text_read(
  GError**                              o_error,
  struct item_text*const                io_text,
  struct bson_node *const               i_element);

extern void
item_text_resize(
  struct item_text*const                io_text,
  struct item_resize_event const*const  i_ctx);

extern int
item_text_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_text const*const          io_text);

#define __item_text_h__
#endif

==> iwrite-2.0.1.0.tar.gz: iwrite-2.0.1.0/src/item_text.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015-2016, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_text_h__

#include "item_common.h"
#include "item_method.h"

struct item_text
{
  gdouble                               m_pos_x1;
  gdouble                               m_pos_y1;
  gdouble                               m_pos_x2;
  gdouble                               m_pos_y2;
  PangoFontDescription*                 m_font; 
  GdkRGBA                               m_color;
  gint                                  m_rotate;
  gdouble                               m_rotation;
  gint                                  m_autowrap;
  gchar*                                m_text;
  gchar*                                m_value;
};

extern void
item_text_assign(
  struct item_text*const                o_text,
  struct item_method*const              o_method);

extern void
item_text_extent_update(
  struct item_text*const                io_text);

extern void
item_text_get_bbox(
  struct geom_rect*const                o_bbox,
  void const*const                      i_object);

extern void
item_text_in_event(
  enum event_type*const                 o_type,
  struct item_text const*const          i_text,
  struct item_in_event const*const      i_ctx);

extern void
item_text_discharge(
  struct item_text*const                io_text);

extern void
item_text_draw(
  struct item_text      *               i_text,
  struct item_draw_context const*const  i_ctx);

extern void
item_text_move(
  struct item_text*const                io_text,
  struct geom_point const*const         i_event);

extern void
item_text_normalize(
  struct item_text*const                io_text,
  double const                          i_bound_width,
  double const                          i_bound_height);

extern int
item_text_property(
  struct item_text*const                io_text);

extern int
item_text_read(
  GError**                              o_error,
  struct item_text*const                io_text,
  struct xml *const               i_element);

extern void
item_text_resize(
  struct item_text*const                io_text,
  struct item_resize_event const*const  i_ctx);

extern int
item_text_write(
  GError**                              o_error,
  FILE*const                            io_fp,
  struct item_text const*const          io_text);

#define __item_text_h__
#endif
